==> haskell-kvitable-1.0.3.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 kvitable
version:              1.0.3.0
visibility:           public
id:                   kvitable-1.0.3.0-GKkHFcdYOrKFeiz2FhRo8e
key:                  kvitable-1.0.3.0-GKkHFcdYOrKFeiz2FhRo8e
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  decc40e9e5362833fbc173b9725f56a8
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Render Data.KVITable.Render.ASCII
    Data.KVITable.Render.HTML

import-dirs:          /usr/lib/ghc-9.2.8/site-local/kvitable-1.0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/kvitable-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.0.3.0-GKkHFcdYOrKFeiz2FhRo8e
depends:
    base-4.16.4.0 containers-0.6.5.1
    lucid-2.11.20230408-E0UShbzmmpd4qsANe5dCAz
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    prettyprinter-1.7.1-HiziM37WgyB7jvtYf8DwHL text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kvitable-1.0.3.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 kvitable
version:              1.0.3.0
visibility:           public
id:                   kvitable-1.0.3.0-9Vwn4HBEatWG7iQuxBaVti
key:                  kvitable-1.0.3.0-9Vwn4HBEatWG7iQuxBaVti
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  6c24a3aa46f4bbe73e0572a29f899a2f
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Render Data.KVITable.Render.ASCII
    Data.KVITable.Render.HTML

import-dirs:          /usr/lib/ghc-9.2.8/site-local/kvitable-1.0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/kvitable-1.0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.0.3.0-9Vwn4HBEatWG7iQuxBaVti
depends:
    base-4.16.4.0 containers-0.6.5.1
    lucid-2.11.20230408-6py9aKljzij8ytTIV5ksnf
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    prettyprinter-1.7.1-KCRmnmMdIcPErCMzcWW5UL text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
